Module error

Module error 

Structs

IoError
A thin wrapper around std::io::Error for I/O failures that do not fit into a more specific category (e.g. reading the .env file).

Enums

PlaceholderError
Errors produced during placeholder resolution.
RedactionError
Errors produced while building the Aho-Corasick redaction automaton.
SecretshError
The unified error type for the entire secretsh binary.
SpawnError
Errors produced when spawning the child process.
TokenizationError
Errors produced by the command-string tokenizer.